@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Ji XiangLong <jixianglong@uniontech.com>
- *
- * Maintainer: WangYu <wangyu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "ccolorpickwidget.h"
 #include "colorpanel.h"
 #include "application.h"
@@ -27,21 +11,26 @@
 //#include "toptoolbar.h"
 #include <DPlatformWindowHandle>
 #include <DWindowManagerHelper>
+const int RADIUS_VALUE = 18;
+const int ARROW_WIDTH = 40;
+const int ARROW_HEIGHT = 30;
 CColorPickWidget::CColorPickWidget(QWidget *parent)
-    : DArrowRectangle(ArrowTop, FloatWidget, parent)
+    : DArrowRectangle(ArrowTop, FloatWindow, parent)
 {
     setWgtAccesibleName(this, "ColorPickWidget");
-    this->setWindowFlag(Qt::FramelessWindowHint);
+    this->setWindowFlags(Qt::FramelessWindowHint);
     this->setWindowFlag(Qt::/*Popup*/Popup);
-    this->setAttribute(Qt::WA_TranslucentBackground, true);
-    this->setArrowWidth(18);
-    this->setArrowHeight(10);
+    this->setAttribute(Qt::WA_TranslucentBackground);
+    setRadiusArrowStyleEnable(true);
+    this->setArrowWidth(ARROW_WIDTH);
+    this->setArrowHeight(ARROW_HEIGHT);
     m_colorPanel = new ColorPanel(this);
     m_colorPanel->setFocusPolicy(Qt::NoFocus);
     this->setFocusPolicy(Qt::NoFocus);
     //this->setContent(m_colorPanel);
     this->hide();
 
+    setRadius(RADIUS_VALUE);
     //connect(m_colorPanel, &ColorPanel::colorChanged, this, &CColorPickWidget::colorChanged);
     connect(m_colorPanel, &ColorPanel::colorChanged, this, [ = ](const QColor & color, EChangedPhase phase) {
         qDebug() << "color ===== " << color << "phase = " << phase;
