@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Ji XiangLong <jixianglong@uniontech.com>
- *
- * Maintainer: ZhangYong <zhangyong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "cattributeitemwidget.h"
 
 
@@ -42,7 +26,8 @@
 #include <QGraphicsDropShadowEffect>
 
 using namespace DrawAttribution;
-
+const int X_OFFSET = 25;
+const int Y_OFFSET = -21;
 DrawAttribution::CColorSettingButton::CColorSettingButton(const QString &text,
                                                           QWidget *parent, bool autoConnect):
     CAttributeWgt(-1, parent), _text(text)
@@ -131,8 +116,8 @@ void DrawAttribution::CColorSettingButton::mousePressEvent(QMouseEvent *event)
         // colorPick->setExpandWidgetVisble(false);
 
         QPoint btnPos = mapToGlobal(QPoint(0, 0));
-        QPoint pos(btnPos.x() + 14,
-                   btnPos.y() + this->height());
+        QPoint pos(btnPos.x() + X_OFFSET,
+                   btnPos.y() + this->height() + Y_OFFSET);
 
         colorPick->show(pos.x(), pos.y());
 
